@@ -47,21 +47,20 @@ describe 'ironic::conductor' do
     it { is_expected.to contain_class('ironic::drivers::agent') }
 
     it 'installs ironic conductor package' do
-      if platform_params.has_key?(:conductor_package)
-        is_expected.to contain_package('ironic-conductor').with(
-          :name   => platform_params[:conductor_package],
-          :ensure => p[:package_ensure],
-          :tag    => ['openstack', 'ironic-package'],
-        )
-        is_expected.to contain_package('ironic-conductor').that_requires('Anchor[ironic::install::begin]')
-        is_expected.to contain_package('ironic-conductor').that_notifies('Anchor[ironic::install::end]')
-      end
+      is_expected.to contain_package('ironic-conductor').with(
+        :name   => platform_params[:conductor_package],
+        :ensure => p[:package_ensure],
+        :tag    => ['openstack', 'ironic-package'],
+      )
     end
 
     it 'ensure ironic conductor service is running' do
       is_expected.to contain_service('ironic-conductor').with(
-        'hasstatus' => true,
-        'tag'       => 'ironic-service',
+        :ensure    => 'running',
+        :name      => platform_params[:conductor_service],
+        :enable    => true,
+        :hasstatus => true,
+        :tag       => 'ironic-service',
       )
     end
 
@@ -90,6 +89,7 @@ describe 'ironic::conductor' do
       is_expected.to contain_ironic_config('conductor/power_state_sync_max_retries').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_failure_recovery_interval').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/periodic_max_workers').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/graceful_shutdown_timeout').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/conductor_group').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/deploy_kernel').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/deploy_ramdisk').with(:value => '<SERVICE DEFAULT>')
@@ -100,6 +100,8 @@ describe 'ironic::conductor' do
       is_expected.to contain_ironic_config('conductor/rescue_kernel_by_arch').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/rescue_ramdisk_by_arch').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/bootloader').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/bootloader_by_arch').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/error_on_ramdisk_config_inconsistency').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/image_download_concurrency').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/deploy_callback_timeout').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/heartbeat_interval').with(:value => '<SERVICE DEFAULT>')
@@ -111,47 +113,50 @@ describe 'ironic::conductor' do
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-          :enabled_hardware_types            => ['ipmi', 'irmc'],
-          :force_power_state_during_sync     => false,
-          :automated_clean                   => false,
-          :cleaning_network                  => '00000000-0000-0000-0000-000000000000',
-          :provisioning_network              => '00000000-0000-0000-0000-000000000000',
-          :rescuing_network                  => '00000000-0000-0000-0000-000000000000',
-          :inspection_network                => '00000000-0000-0000-0000-000000000000',
-          :cleaning_disk_erase               => 'metadata',
-          :http_url                          => 'http://host:port',
-          :http_root                         => '/src/www',
-          :force_raw_images                  => false,
-          :configdrive_use_object_store      => true,
-          :configdrive_swift_container       => 'cont',
-          :inspect_wait_timeout              => 600,
-          :default_boot_option               => 'local',
-          :default_boot_mode                 => 'uefi',
-          :port_setup_delay                  => '15',
-          :soft_power_off_timeout            => 600,
-          :power_state_change_timeout        => '300',
-          :sync_power_state_interval         => 120,
-          :sync_power_state_workers          => 2,
-          :power_state_sync_max_retries      => 5,
-          :power_failure_recovery_interval   => 120,
-          :periodic_max_workers              => 4,
-          :conductor_group                   => 'in-the-closet-to-the-left',
-          :deploy_kernel                     => 'http://host/deploy.kernel',
-          :deploy_ramdisk                    => 'http://host/deploy.ramdisk',
-          :deploy_kernel_by_arch             => {'x86_64' => 'http://host/deploy.kernel'},
-          :deploy_ramdisk_by_arch            => {'x86_64' => 'http://host/deploy.ramdisk'},
-          :rescue_kernel                     => 'http://host/rescue.kernel',
-          :rescue_ramdisk                    => 'http://host/rescue.ramdisk',
-          :rescue_kernel_by_arch             => {'x86_64' => 'http://host/rescue.kernel'},
-          :rescue_ramdisk_by_arch            => {'x86_64' => 'http://host/rescue.ramdisk'},
-          :bootloader                        => 'http://host/bootloader',
-          :allow_provisioning_in_maintenance => false,
-          :image_download_concurrency        => 20,
-          :deploy_callback_timeout           => 1800,
-          :heartbeat_interval                => 10,
-          :heartbeat_timeout                 => 60,
-          :max_concurrent_deploy             => 250,
-          :max_concurrent_clean              => 50,
+          :enabled_hardware_types                => ['ipmi', 'irmc'],
+          :force_power_state_during_sync         => false,
+          :automated_clean                       => false,
+          :cleaning_network                      => '00000000-0000-0000-0000-000000000000',
+          :provisioning_network                  => '00000000-0000-0000-0000-000000000000',
+          :rescuing_network                      => '00000000-0000-0000-0000-000000000000',
+          :inspection_network                    => '00000000-0000-0000-0000-000000000000',
+          :cleaning_disk_erase                   => 'metadata',
+          :http_url                              => 'http://host:port',
+          :http_root                             => '/src/www',
+          :force_raw_images                      => false,
+          :configdrive_use_object_store          => true,
+          :configdrive_swift_container           => 'cont',
+          :inspect_wait_timeout                  => 600,
+          :default_boot_option                   => 'local',
+          :default_boot_mode                     => 'uefi',
+          :port_setup_delay                      => '15',
+          :soft_power_off_timeout                => 600,
+          :power_state_change_timeout            => '300',
+          :sync_power_state_interval             => 120,
+          :sync_power_state_workers              => 2,
+          :power_state_sync_max_retries          => 5,
+          :power_failure_recovery_interval       => 120,
+          :periodic_max_workers                  => 4,
+          :graceful_shutdown_timeout             => 60,
+          :conductor_group                       => 'in-the-closet-to-the-left',
+          :deploy_kernel                         => 'http://host/deploy.kernel',
+          :deploy_ramdisk                        => 'http://host/deploy.ramdisk',
+          :deploy_kernel_by_arch                 => {'x86_64' => 'http://host/deploy.kernel'},
+          :deploy_ramdisk_by_arch                => {'x86_64' => 'http://host/deploy.ramdisk'},
+          :rescue_kernel                         => 'http://host/rescue.kernel',
+          :rescue_ramdisk                        => 'http://host/rescue.ramdisk',
+          :rescue_kernel_by_arch                 => {'x86_64' => 'http://host/rescue.kernel'},
+          :rescue_ramdisk_by_arch                => {'x86_64' => 'http://host/rescue.ramdisk'},
+          :bootloader                            => 'http://host/bootloader',
+          :bootloader_by_arch                    => {'x86_64' => 'http://host/bootloader'},
+          :error_on_ramdisk_config_inconsistency => false,
+          :allow_provisioning_in_maintenance     => false,
+          :image_download_concurrency            => 20,
+          :deploy_callback_timeout               => 1800,
+          :heartbeat_interval                    => 10,
+          :heartbeat_timeout                     => 60,
+          :max_concurrent_deploy                 => 250,
+          :max_concurrent_clean                  => 50,
         )
       end
       it 'should replace default parameter with new value' do
@@ -180,6 +185,7 @@ describe 'ironic::conductor' do
         is_expected.to contain_ironic_config('conductor/power_state_sync_max_retries').with_value(p[:power_state_sync_max_retries])
         is_expected.to contain_ironic_config('conductor/power_failure_recovery_interval').with_value(p[:power_failure_recovery_interval])
         is_expected.to contain_ironic_config('conductor/periodic_max_workers').with_value(p[:periodic_max_workers])
+        is_expected.to contain_ironic_config('conductor/graceful_shutdown_timeout').with_value(p[:graceful_shutdown_timeout])
         is_expected.to contain_ironic_config('conductor/conductor_group').with_value(p[:conductor_group])
         is_expected.to contain_ironic_config('conductor/deploy_kernel').with_value(p[:deploy_kernel])
         is_expected.to contain_ironic_config('conductor/deploy_ramdisk').with_value(p[:deploy_ramdisk])
@@ -190,6 +196,8 @@ describe 'ironic::conductor' do
         is_expected.to contain_ironic_config('conductor/rescue_kernel_by_arch').with_value('x86_64:http://host/rescue.kernel')
         is_expected.to contain_ironic_config('conductor/rescue_ramdisk_by_arch').with_value('x86_64:http://host/rescue.ramdisk')
         is_expected.to contain_ironic_config('conductor/bootloader').with_value(p[:bootloader])
+        is_expected.to contain_ironic_config('conductor/bootloader_by_arch').with_value('x86_64:http://host/bootloader')
+        is_expected.to contain_ironic_config('conductor/error_on_ramdisk_config_inconsistency').with_value(false)
         is_expected.to contain_ironic_config('conductor/allow_provisioning_in_maintenance').with_value(p[:allow_provisioning_in_maintenance])
         is_expected.to contain_ironic_config('DEFAULT/image_download_concurrency').with_value(p[:image_download_concurrency])
         is_expected.to contain_ironic_config('conductor/deploy_callback_timeout').with_value(p[:deploy_callback_timeout])
@@ -217,7 +225,8 @@ describe 'ironic::conductor' do
           end
         when 'RedHat'
           let :platform_params do
-            { :conductor_service => 'ironic-conductor' }
+            { :conductor_package => 'openstack-ironic-conductor',
+              :conductor_service => 'openstack-ironic-conductor' }
           end
         end
 
