@@ -47,14 +47,6 @@ describe 'ironic' do
         )
       end
 
-      it 'installs ironic-lib package' do
-        is_expected.to contain_package('ironic-lib').with(
-          :ensure => 'present',
-          :name   => platform_params[:lib_package_name],
-          :tag    => ['openstack', 'ironic-package'],
-        )
-      end
-
       it 'passes purge to resource' do
         is_expected.to contain_resources('ironic_config').with({
           :purge => false
@@ -83,11 +75,11 @@ describe 'ironic' do
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :kombu_compression               => '<SERVICE DEFAULT>',
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -95,9 +87,12 @@ describe 'ironic' do
           :kombu_ssl_version               => '<SERVICE DEFAULT>',
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
           :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__notifications('ironic_config').with(
@@ -126,10 +121,10 @@ describe 'ironic' do
           :rabbit_use_ssl                     => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :kombu_reconnect_delay              => '5.0',
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => true,
           :kombu_compression                  => 'gzip',
           :kombu_ssl_ca_certs                 => '/etc/ca.cert',
           :kombu_ssl_certfile                 => '/etc/certfile',
@@ -137,9 +132,12 @@ describe 'ironic' do
           :kombu_ssl_version                  => 'TLSv1',
           :rabbit_ha_queues                   => true,
           :rabbit_quorum_queue                => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_use_queue_manager           => true,
+          :rabbit_stream_fanout               => true,
           :rabbit_enable_cancel_on_failover   => false,
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                => 'messagingv2',
@@ -172,10 +170,10 @@ describe 'ironic' do
           :rabbit_use_ssl                  => true,
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
-          :heartbeat_in_pthread            => true,
           :rabbit_qos_prefetch_count       => 0,
           :kombu_reconnect_delay           => '5.0',
           :amqp_durable_queues             => true,
+          :amqp_auto_delete                => true,
           :kombu_compression               => 'gzip',
           :kombu_ssl_ca_certs              => '/etc/ca.cert',
           :kombu_ssl_certfile              => '/etc/certfile',
@@ -183,9 +181,12 @@ describe 'ironic' do
           :kombu_ssl_version               => 'TLSv1',
           :rabbit_ha_queues                => true,
           :rabbit_quorum_queue             => true,
+          :rabbit_transient_queues_ttl     => 60,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :use_queue_manager               => true,
+          :rabbit_stream_fanout            => true,
           :enable_cancel_on_failover       => false,
         )
         is_expected.to contain_oslo__messaging__notifications('ironic_config').with(
@@ -209,11 +210,9 @@ describe 'ironic' do
       let :platform_params do
         case facts[:os]['family']
         when 'Debian'
-          { :common_package_name => 'ironic-common',
-            :lib_package_name    => 'python3-ironic-lib' }
+          { :common_package_name => 'ironic-common' }
         when 'RedHat'
-          { :common_package_name => 'openstack-ironic-common',
-            :lib_package_name    => 'python3-ironic-lib' }
+          { :common_package_name => 'openstack-ironic-common' }
         end
       end
 
