@@ -31,13 +31,14 @@ describe 'ironic::inspector::db::postgresql' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts())
+        facts.merge(OSDefaults.get_facts({
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
+        }))
       end
 
-      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
-      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
-        it_behaves_like 'ironic::inspector::db::postgresql'
-      end
+      it_behaves_like 'ironic::inspector::db::postgresql'
     end
   end
 
