@@ -108,6 +108,7 @@ describe 'ironic::inspector' do
     end
 
     it 'configures inspector.conf' do
+      is_expected.to contain_ironic_inspector_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('DEFAULT/auth_strategy').with_value(p[:auth_strategy])
       is_expected.to contain_ironic_inspector_config('DEFAULT/timeout').with_value('<SERVICE DEFAULT>')
@@ -135,11 +136,11 @@ describe 'ironic::inspector' do
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
         :kombu_failover_strategy         => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => '<SERVICE DEFAULT>',
+        :amqp_auto_delete                => '<SERVICE DEFAULT>',
         :kombu_compression               => '<SERVICE DEFAULT>',
         :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
         :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -147,6 +148,7 @@ describe 'ironic::inspector' do
         :kombu_ssl_version               => '<SERVICE DEFAULT>',
         :rabbit_ha_queues                => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
@@ -160,7 +162,7 @@ describe 'ironic::inspector' do
 
     it 'should contain file /etc/ironic-inspector/dnsmasq.conf' do
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with(
-        'ensure'  => 'present',
+        'ensure'  => 'file',
         'content' => /pxelinux/,
         'tag'     => 'ironic-inspector-dnsmasq-file',
       )
@@ -206,10 +208,10 @@ describe 'ironic::inspector' do
     end
     it 'should contain file /tftpboot/pxelinux.cfg/default' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg/default').with(
+        'ensure'  => 'file',
         'owner'   => 'ironic-inspector',
         'group'   => 'ironic-inspector',
         'seltype' => 'tftpdir_t',
-        'ensure'  => 'present',
         'content' => /default/,
         'tag'     => 'ironic-inspector-dnsmasq-file',
       )
@@ -222,6 +224,7 @@ describe 'ironic::inspector' do
       before :each do
         params.merge!(
           :dhcp_debug                         => true,
+          :host                               => 'localhost',
           :listen_address                     => '127.0.0.1',
           :api_max_limit                      => 100,
           :pxe_transfer_protocol              => 'http',
@@ -251,10 +254,10 @@ describe 'ironic::inspector' do
           :rabbit_use_ssl                     => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :kombu_reconnect_delay              => '5.0',
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => true,
           :kombu_compression                  => 'gzip',
           :kombu_ssl_ca_certs                 => '/etc/ca.cert',
           :kombu_ssl_certfile                 => '/etc/certfile',
@@ -262,6 +265,7 @@ describe 'ironic::inspector' do
           :kombu_ssl_version                  => 'TLSv1',
           :rabbit_ha_queues                   => true,
           :rabbit_quorum_queue                => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
@@ -269,6 +273,7 @@ describe 'ironic::inspector' do
         )
       end
       it 'should replace default parameter with new value' do
+        is_expected.to contain_ironic_inspector_config('DEFAULT/host').with_value(p[:host])
         is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value(p[:listen_address])
         is_expected.to contain_ironic_inspector_config('DEFAULT/api_max_limit').with_value(100)
         is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value(p[:detect_boot_mode])
@@ -289,10 +294,10 @@ describe 'ironic::inspector' do
           :rabbit_use_ssl                  => true,
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
-          :heartbeat_in_pthread            => true,
           :rabbit_qos_prefetch_count       => 0,
           :kombu_reconnect_delay           => '5.0',
           :amqp_durable_queues             => true,
+          :amqp_auto_delete                => true,
           :kombu_compression               => 'gzip',
           :kombu_ssl_ca_certs              => '/etc/ca.cert',
           :kombu_ssl_certfile              => '/etc/certfile',
@@ -300,6 +305,7 @@ describe 'ironic::inspector' do
           :kombu_ssl_version               => 'TLSv1',
           :rabbit_ha_queues                => true,
           :rabbit_quorum_queue             => true,
+          :rabbit_transient_queues_ttl     => 60,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
@@ -318,7 +324,7 @@ describe 'ironic::inspector' do
 
       it 'should contain file /etc/ironic-inspector/dnsmasq.conf' do
         is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with(
-          'ensure'  => 'present',
+          'ensure'  => 'file',
           'content' => /ipxe/,
           'tag'     => 'ironic-inspector-dnsmasq-file',
         )
@@ -359,10 +365,10 @@ describe 'ironic::inspector' do
       end
       it 'should contain file /var/www/httpboot/inspector.ipxe' do
         is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with(
+          'ensure'  => 'file',
           'owner'   => 'ironic-inspector',
           'group'   => 'ironic-inspector',
           'seltype' => 'httpd_sys_content_t',
-          'ensure'  => 'present',
           'content' => /ipxe/,
         )
         is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with_content(
@@ -421,18 +427,18 @@ describe 'ironic::inspector' do
       end
       it 'should contain directory /tftpboot/ppc64le with selinux type tftpdir_t' do
         is_expected.to contain_file('/tftpboot/ppc64le').with(
+          'ensure'  => 'directory',
           'owner'   => 'ironic-inspector',
           'group'   => 'ironic-inspector',
-          'ensure'  => 'directory',
           'seltype' => 'tftpdir_t',
         )
       end
       it 'should contain file /tftpboot/ppc64le/default' do
         is_expected.to contain_file('/tftpboot/ppc64le/default').with(
+          'ensure'  => 'file',
           'owner'   => 'ironic-inspector',
           'group'   => 'ironic-inspector',
           'seltype' => 'tftpdir_t',
-          'ensure'  => 'present',
           'content' => /default/,
         )
         is_expected.to contain_file('/tftpboot/ppc64le/default').with_content(
@@ -455,10 +461,10 @@ describe 'ironic::inspector' do
       end
       it 'should contain file /tftpboot/ppc64le/default' do
         is_expected.to contain_file('/tftpboot/ppc64le/default').with(
+          'ensure'  => 'file',
           'owner'   => 'ironic-inspector',
           'group'   => 'ironic-inspector',
           'seltype' => 'tftpdir_t',
-          'ensure'  => 'present',
           'content' => /default/,
           'tag'     => 'ironic-inspector-dnsmasq-file',
         )
