@@ -32,6 +32,7 @@ describe 'ironic::keystone::auth_inspector' do
         :configure_user      => true,
         :configure_user_role => true,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'ironic-inspector',
         :service_type        => 'baremetal-introspection',
         :auth_name           => 'ironic-inspector',
@@ -40,7 +41,7 @@ describe 'ironic::keystone::auth_inspector' do
         :password            => 'ironic-inspector_password',
         :email               => 'ironic-inspector@localhost',
         :tenant              => 'services',
-        :roles               => ['admin'],
+        :roles               => ['admin', 'service'],
         :system_scope        => 'all',
         :system_roles        => [],
         :public_url          => 'http://127.0.0.1:5050',
@@ -55,12 +56,13 @@ describe 'ironic::keystone::auth_inspector' do
           :auth_name           => 'alt_ironic-inspector',
           :email               => 'alt_ironic-inspector@alt_localhost',
           :tenant              => 'alt_service',
-          :roles               => ['admin', 'service'],
+          :roles               => ['admin'],
           :system_scope        => 'alt_all',
           :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
+          :configure_service   => false,
           :service_description => 'Alternative Bare Metal Introspection Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_baremetal-introspection',
@@ -74,6 +76,7 @@ describe 'ironic::keystone::auth_inspector' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_baremetal-introspection',
         :auth_name           => 'alt_ironic-inspector',
@@ -82,7 +85,7 @@ describe 'ironic::keystone::auth_inspector' do
         :password            => 'ironic-inspector_password',
         :email               => 'alt_ironic-inspector@alt_localhost',
         :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
+        :roles               => ['admin'],
         :system_scope        => 'alt_all',
         :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
