@@ -31,6 +31,7 @@ describe 'ironic::keystone::auth' do
         :configure_user      => true,
         :configure_user_role => true,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'ironic',
         :service_type        => 'baremetal',
         :service_description => 'Ironic Bare Metal Provisioning Service',
@@ -39,7 +40,7 @@ describe 'ironic::keystone::auth' do
         :password            => 'ironic_password',
         :email               => 'ironic@localhost',
         :tenant              => 'services',
-        :roles               => ['admin'],
+        :roles               => ['admin', 'service'],
         :system_scope        => 'all',
         :system_roles        => [],
         :public_url          => 'http://127.0.0.1:6385',
@@ -54,12 +55,13 @@ describe 'ironic::keystone::auth' do
           :auth_name           => 'alt_ironic',
           :email               => 'alt_ironic@alt_localhost',
           :tenant              => 'alt_service',
-          :roles               => ['admin', 'service'],
+          :roles               => ['admin'],
           :system_scope        => 'alt_all',
           :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
+          :configure_service   => false,
           :service_description => 'Alternative Ironic Bare Metal Provisioning Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_baremetal',
@@ -73,6 +75,7 @@ describe 'ironic::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_baremetal',
         :service_description => 'Alternative Ironic Bare Metal Provisioning Service',
@@ -81,7 +84,7 @@ describe 'ironic::keystone::auth' do
         :password            => 'ironic_password',
         :email               => 'alt_ironic@alt_localhost',
         :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
+        :roles               => ['admin'],
         :system_scope        => 'alt_all',
         :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
